Package: ModStatR
Type: Package
Title: Statistical Modelling in Action with R
Version: 1.4.2
Date: 2026-05-03
Depends: R (>= 3.5.0)
Imports: stats, boot, jmuOutlier, ellipse, hypergeo, gsl
Suggests: BioStatR, ggplot2, DescTools, FactoMineR, GGally, ISLR,
        Kendall, MASS, MBESS, MVN, PCAmixdata, RColorBrewer, SuppDists,
        ade4, adegraphics, broom, car, coin, combinat, corpcor,
        corrplot, devtools, dplyr, factoextra, finalfit, ggcorrplot,
        ggdendro, ggiraphExtra, ggpubr, glmnet, hnp, lattice, leaps,
        mice, mvtnorm, naniar, ppcor, pspearman, pwr, questionr, rgl,
        rms, vcd, vegan, yarrr, testthat (>= 3.0.0), covr
Authors@R: c(
	person(given = "Frederic", family= "Bertrand", role = c("cre", "aut"), email = "frederic.bertrand@lecnam.net", comment = c(ORCID = "0000-0002-0837-8281")),
	person(given = "Emmanuelle", family= "Claeys", role = c("aut"), email = "emmanuelle.claeys@unistra.fr"),
	person(given = "Myriam", family= "Maumy-Bertrand", role = c("aut"), email = "myriam.maumy@ehesp.fr", comment = c(ORCID = "0000-0002-4615-1512")))
Author: Frederic Bertrand [cre, aut] (ORCID:
    <https://orcid.org/0000-0002-0837-8281>),
  Emmanuelle Claeys [aut],
  Myriam Maumy-Bertrand [aut] (ORCID:
    <https://orcid.org/0000-0002-4615-1512>)
Maintainer: Frederic Bertrand <frederic.bertrand@lecnam.net>
Description: Datasets and functions for the book "Modélisation statistique par la pratique avec R", F. Bertrand, E. Claeys and M. Maumy-Bertrand (2019, ISBN:9782100793525, Dunod, Paris). The first chapter of the book is dedicated to an introduction to the R statistical software. The second chapter deals with correlation analysis: Pearson, Spearman and Kendall simple, multiple and partial correlation coefficients. New wrapper functions for permutation tests or bootstrap of matrices of correlation are provided with the package. The third chapter is dedicated to data exploration with factorial analyses (PCA, CA, MCA, MDA) and clustering. The fourth chapter is dedicated to regression analysis: fitting and model diagnostics are detailed. The exercises focus on covariance analysis, logistic regression, Poisson regression, two-way analysis of variance for fixed or random factors. Various example datasets are shipped with the package: for instance on pokemon, world of warcraft, house tasks or food nutrition analyses.
LazyLoad: yes
LazyData: yes
License: GPL-3
Encoding: UTF-8
Language: fr-FR
Classification/MSC:
URL: https://fbertran.github.io/homepage/,
        https://fbertran.github.io/ModStatR/,
        https://github.com/fbertran/ModStatR
BugReports: https://github.com/fbertran/ModStatR/issues
RoxygenNote: 7.3.3
Config/testthat/edition: 3
NeedsCompilation: no
Packaged: 2026-05-03 15:23:03 UTC; bertran7
Repository: CRAN
Date/Publication: 2026-05-03 15:50:09 UTC
Built: R 4.5.2; ; 2026-05-03 17:52:01 UTC; unix
