# Generated by roxygen2: do not edit by hand

export(Gauss2F1)
export(Gauss2F1gsl)
export(boot.mcor.ic)
export(corrdist)
export(corrdistapprox)
export(corrdistapprox2)
export(my.confidence.region)
export(perm.cor.mtest)
export(ref.cor.mtest)
export(ref.cor.test)
export(rho)
export(rho.mult)
import(ellipse)
importFrom(boot,boot.ci)
importFrom(graphics,abline)
importFrom(graphics,lines)
importFrom(graphics,par)
importFrom(graphics,plot)
importFrom(graphics,points)
importFrom(graphics,polygon)
importFrom(graphics,rect)
importFrom(gsl,hyperg_2F1)
importFrom(hypergeo,hypergeo)
importFrom(jmuOutlier,perm.cor.test)
importFrom(stats,cor)
importFrom(stats,cor.test)
importFrom(stats,integrate)
importFrom(stats,na.omit)
importFrom(stats,qt)
