#' @keywords internal
#' @name ModStatR-package
#' @aliases ModStatR-package ModStatR NULL
#'
#' @references \emph{Modélisation statistique par la pratique avec R}, Frédéric Bertrand, Emmanuelle Claeys, Myriam Maumy-Bertrand, 2019, ISBN:9782100793525, Dunod, Paris, \url{https://www.dunod.com/sciences-techniques/modelisation-statistique-par-pratique-avec-r-cours-et-exercices-corriges}, \url{https://github.com/fbertran/ModStatR/} et \url{https://fbertran.github.io/ModStatR/}
#' 
#' @examples
#' set.seed(314)
"_PACKAGE"

#' @importFrom graphics abline lines par plot points polygon rect
#' @importFrom stats qt cor cor.test integrate na.omit
#' @importFrom boot boot.ci
#' @importFrom hypergeo hypergeo
#' @importFrom gsl hyperg_2F1
#' @importFrom jmuOutlier perm.cor.test
#' @import ellipse
#' 
NULL